Django JIssues
==============

Basic issue tracking abstract data models for Django projects.

Usage
-----

1. Derive concrete classes from jissues.model.*Base abstract base classes
2. Derive admin classes from jissues.admin.*Base classes and register admins
3. Add whatever fields you need to concrete classes on top of abstract base
